Clojure only.

boundary.mcp.core.handlers

Pure JSON-RPC dispatch. (handle registry msg) -> response map for a request, or nil for a notification / handled-without-reply message. No I/O; the shell transport feeds parsed messages in and writes responses out.

Pure JSON-RPC dispatch. `(handle registry msg)` -> response map for a
request, or nil for a notification / handled-without-reply message. No I/O;
the shell transport feeds parsed messages in and writes responses out.
raw docstring

handleclj

(handle registry msg)

Dispatch a parsed JSON-RPC message against registry. Returns a response map for requests; nil for notifications and unknown notifications.

Dispatch a parsed JSON-RPC message against `registry`. Returns a response
map for requests; nil for notifications and unknown notifications.
sourceraw docstring

server-infoclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries