Pure JSON-RPC dispatch. (handle registry msg) -> response map for a
request, or nil for a notification / handled-without-reply message. No I/O;
the shell transport feeds parsed messages in and writes responses out.
Pure JSON-RPC dispatch. `(handle registry msg)` -> response map for a request, or nil for a notification / handled-without-reply message. No I/O; the shell transport feeds parsed messages in and writes responses out.
(handle registry msg)Dispatch a parsed JSON-RPC message against registry. Returns a response
map for requests; nil for notifications and unknown notifications.
Dispatch a parsed JSON-RPC message against `registry`. Returns a response map for requests; nil for notifications and unknown notifications.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |